@@ -96,6 +96,7 @@ struct msgs {
     int numsel;		/* Number of msgs selected           */
 
     int curmsg;		/* Number of current msg if any      */
+
     int msgflags;	/* Folder attributes (READONLY, etc) */
     char *foldpath;	/* Pathname of folder                */
 
@@ -167,6 +168,10 @@ struct msgs {
 #define make_all_public(mp) \
            ((mp)->attrstats = 0)
 
+/*
+ * macros for folder attributes
+ */
+#define is_readonly(mp)     ((mp)->msgflags & READONLY)
 #define other_files(mp)     ((mp)->msgflags & OTHERS)
 
 #define	NULLMP	((struct msgs *) 0)
