@@ -27,9 +27,9 @@ getans (char *prompt, struct swit *ansp)
     char *cp, **cpp;
 
     if (!(setjmp (sigenv))) {
-	istat = signal (SIGINT, intrser);
+	istat = SIGNAL (SIGINT, intrser);
     } else {
-	signal (SIGINT, istat);
+	SIGNAL (SIGINT, istat);
 	return NULL;
     }
 
@@ -58,7 +58,7 @@ getans (char *prompt, struct swit *ansp)
 		printf (" -%s unknown. Hit <CR> for help.\n", *cpp);
 		continue;
 	    default: 
-		signal (SIGINT, istat);
+		SIGNAL (SIGINT, istat);
 		return cpp;
 	}
     }
@@ -68,5 +68,8 @@ getans (char *prompt, struct swit *ansp)
 static RETSIGTYPE
 intrser (int i)
 {
-    longjmp (sigenv, 1);  /* should this be siglongjmp? */
+    /*
+     * should this be siglongjmp?
+     */
+    longjmp (sigenv, 1);
 }
