@@ -13,10 +13,10 @@ m_setcur (struct msgs *mp, int num)
 {
     int i, public;
 
-    public = !(mp->msgflags & READONLY);
+    public = mp->msgflags & READONLY ? 0 : 1;
     for (i = 0; mp->msgattrs[i]; i++)
 	if (!strcmp (mp->msgattrs[i], current)) {
-	    public = !(mp->attrstats & (1 << (FFATTRSLOT + i)));
+	    public = is_seq_private (mp, i) ? 0 : 1;
 	    break;
 	}
 
