@@ -26,7 +26,7 @@ m_setseq (struct msgs *mp)
     for (; *ap; ap++)
 	if (m_seqnew (mp, *ap, -1))
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
-		if (mp->msgstats[msgnum] & SELECTED)
+		if (is_selected (mp, msgnum))
 		    m_seqadd (mp, *ap, msgnum, -1);
 
     if (dp)
