@@ -27,7 +27,7 @@ refile (char **arg, char *file)
 	    vec[vecp++] = *arg++;
     vec[vecp] = NULL;
 
-    m_update();
+    m_update();		/* update the context file */
     fflush(stdout);
 
     switch (pid = vfork()) {
