@@ -11,7 +11,7 @@
 int
 remdir (char *dir)
 {
-    m_update();
+    m_update();		/* update the context file */
     fflush(stdout);
 
     if (rmdir(dir) == NOTOK) {
