@@ -49,9 +49,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -146,7 +146,7 @@ main (int argc, char **argv)
     m_replace (pfolder, folder);	/* update current folder */
     if (mp->lowsel != mp->curmsg)
 	m_setcur (mp, mp->lowsel);
-    m_sync (mp);
+    m_sync (mp);	/* synchronize message sequences */
     m_fmsg (mp);	/* free folder/message structure */
     m_update ();	/* update the context file       */
     done (0);
@@ -181,3 +181,4 @@ make_comp (char **ap)
 	if (!isalnum (*cp) && *cp != '-')
 	    adios (NULL, "invalid component name %s", *ap);
 }
+
