@@ -86,8 +86,7 @@ annosbr (int src, char *file, char *comp, char *text, int inplace, int datesw)
 	cpydata (fd, src, tmpfil, file);
 	close (fd);
 	unlink (tmpfil);
-    }
-    else {
+    } else {
 	strcpy (buffer, m_backup (file));
 	if (rename (file, buffer) == NOTOK) {
 	    switch (errno) {
