@@ -7,7 +7,7 @@
 
 #include <h/mh.h>
 #include <h/addrsbr.h>
-#include <h/formatsbr.h>
+#include <h/fmt_scan.h>
 
 #define	NADDRS	100
 
@@ -65,9 +65,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -184,7 +184,7 @@ process (char *arg, int length, int norm)
 	if (cptr)
 	    cptr->c_text = p->pq_error;
 
-	fmtscan (fmt, buffer, length, dat);
+	fmt_scan (fmt, buffer, length, dat);
 	fputs (buffer, stdout);
 
 	free (p->pq_text);
