@@ -21,8 +21,8 @@
 #include <signal.h>
 
 #ifndef	sigmask
-#define	sigmask(s) (1 << ((s) - 1))
-#endif not sigmask
+# define sigmask(s) (1 << ((s) - 1))
+#endif /* not sigmask */
 
 #ifdef ridge
 # undef SIGTSTP
@@ -32,7 +32,7 @@
 # include <sys/wait.h>
 # include <sys/time.h>
 # include <sys/resource.h>
-#endif SIGTSTP
+#endif /* SIGTSTP */
 
 #define	RCFILE ".bbrc"
 #define	NBB 100
