@@ -58,9 +58,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -142,6 +142,8 @@ main (int argc, char **argv)
 	adios (NULL, "unable to allocate burst storage");
 
     hi = mp->hghmsg + 1;
+
+    /* burst all the SELECTED messages */
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 	if (is_selected (mp, msgnum))
 	    burst (smsgs, msgnum, inplace, quietsw, verbosw);
@@ -152,12 +154,12 @@ main (int argc, char **argv)
     if (inplace) {
 	if (mp->lowsel != mp->curmsg)
 	    m_setcur (mp, mp->lowsel);
-    }
-    else
+    } else {
 	if (hi <= mp->hghmsg)
 	    m_setcur (mp, hi);
+    }
 
-    m_sync (mp);
+    m_sync (mp);	/* synchronize message sequences */
     m_fmsg (mp);	/* free folder/message structure */
     m_update ();	/* update the context file       */
     done (0);
