@@ -80,9 +80,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -165,12 +165,12 @@ main (int argc, char **argv)
 		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	}
-	else
+	} else {
 	    if (msg)
 		adios (NULL, "only one message at a time!");
 	    else
 		msg = cp;
+	}
     }
 
     cwd = getcpy (pwd ());
@@ -178,8 +178,10 @@ main (int argc, char **argv)
     if (!m_find ("path"))
 	free (path ("./", TFOLDER));
 
-    if ((dfolder || m_find ("Draft-Folder")) && !folder && msg && !file)
-	file = msg, msg = NULL;
+    if ((dfolder || m_find ("Draft-Folder")) && !folder && msg && !file) {
+	file = msg;
+	msg = NULL;
+    }
     if (form && (folder || msg))
 	    adios (NULL, "can't mix forms and folders/msgs");
 
