@@ -39,7 +39,7 @@ distout (char *drft, char *msgnam, char *backup)
     chmod (drft, m_gmprot ());
 
     ready_msg (msgnam);
-    lseek (hdrfd, (off_t) 0, 0);	/* msgnam not accurate */
+    lseek (hdrfd, (off_t) 0, SEEK_SET); /* msgnam not accurate */
     cpydata (hdrfd, fileno (ofp), msgnam, drft);
 
     for (state = FLD, resent = NULL;;)
@@ -110,7 +110,7 @@ process: ;
     free (resent);
 
     if (txtfd != NOTOK) {
-	lseek (txtfd, (off_t) 0, 0);	/* msgnam not accurate */
+	lseek (txtfd, (off_t) 0, SEEK_SET); /* msgnam not accurate */
 	cpydata (txtfd, fileno (ofp), msgnam, drft);
     }
 
