@@ -6,7 +6,7 @@
  */
 
 #include <h/mh.h>
-#include <h/formatsbr.h>
+#include <h/fmt_scan.h>
 #include <zotnet/tws/tws.h>
 
 #define	NDATES 100
@@ -140,7 +140,7 @@ process (char *date, int length)
     FINDCOMP (cptr, "text");
     if (cptr)
 	cptr->c_text = date;
-    fmtscan (fmt, buffer, length, dat);
+    fmt_scan (fmt, buffer, length, dat);
     fputs (buffer, stdout);
 
     return status;
