@@ -29,6 +29,8 @@
 # define ntohl(n) (n)
 #endif
 
+#include <fcntl.h>
+
 extern int errno;
 
 /*
@@ -528,7 +530,7 @@ map_write (char *mailbox, int md, int id, long last, off_t start,
 	    return NOTOK;
 	}
 
-	switch (i = mbx_read (fp, (off_t)0, &rp, noisy)) {
+	switch (i = mbx_read (fp, 0, &rp, noisy)) {
 	    case NOTOK:
 		fclose (fp);
 		mbx_close (file, fd);
