@@ -6,8 +6,8 @@
  */
 
 #include <h/mh.h>
-#include <h/formatsbr.h>
-#include <h/fmtcompile.h>
+#include <h/fmt_scan.h>
+#include <h/fmt_compile.h>
 #include <h/scansbr.h>
 
 static struct swit switches[] = {
