@@ -62,15 +62,15 @@ static struct swit switches[] = {
 
 extern int errno;
 
-static int fshort   = 0;	/* output only folder names                 */
-static int fcreat   = 0;	/* should we ask to create new folders?     */
-static int fpack    = 0;	/* are we packing the folder?               */
-static int fverb    = 0;	/* print actions taken while packing folder */
-static int fheader  = 0;	/* should we output a header?               */
-static int frecurse = 0;	/* recurse through subfolders               */
-static int ftotonly = 0;	/* should we only output the totals?        */
-static int msgtot   = 0;	/* total number of messages                 */
-static int foldtot  = 0;	/* total number of folders                  */
+static int fshort        = 0;	/* output only folder names                 */
+static int fcreat        = 0;	/* should we ask to create new folders?     */
+static int fpack         = 0;	/* are we packing the folder?               */
+static int fverb         = 0;	/* print actions taken while packing folder */
+static int fheader       = 0;	/* should we output a header?               */
+static int frecurse      = 0;	/* recurse through subfolders               */
+static int ftotonly      = 0;	/* should we only output the totals?        */
+static int total_msgs    = 0;	/* total number of messages                 */
+static int total_folders = 0;	/* total number of folders                  */
 
 static int start    = 0;
 static int foldp    = 0;
@@ -78,20 +78,42 @@ static int foldp    = 0;
 static char *mhdir;
 static char *stack = "Folder-Stack";
 static char folder[BUFSIZ];
-static char *folds[NFOLDERS + 1];
+
+#define NUMFOLDERS 256
+
+/*
+ * This is how many folders we currently can hold in the array
+ * `folds'.  We increase this amount by NUMFOLDERS at a time.
+ */
+static int maxfolders;
+static char **folds;
+
+struct Folder {
+    char *name;
+    int nummsg;
+    int curmsg;
+    int lowmsg;
+    int hghmsg;
+    int others;		/* others == 1 if other files in folder */
+    int error;		/* error == 1 for unreadable folder     */
+};
+
+static struct Folder fi;
 
 /*
  * static prototypes
  */
 static void dodir (char *);
-static int pfold (char *, char *);
+static int get_folder_info (char *, char *);
+static void print_header (void);
+static void print_folder_info (struct Folder *, char *);
 static void print_totals (void);
 static int sfold (struct msgs *, char *);
 static void addir (char *);
 static void addfold (char *);
 static int compare (char *, char *);
-static void doreadonly (void);
-static struct msgs *tfold (struct msgs *);
+static void do_readonly (void);
+static struct msgs *pack_folder (struct msgs *);
 
 
 main (int argc, char **argv)
@@ -107,7 +129,7 @@ main (int argc, char **argv)
 #endif
     invo_name = r1bindex (argv[0], '/');
     if (argv[0][strlen (argv[0]) - 1] == 's')
-	all++;
+	all = 1;
     if ((cp = m_find (invo_name))) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
@@ -135,7 +157,7 @@ main (int argc, char **argv)
 		    done (1);
 
 		case ALLSW: 
-		    all++;
+		    all = 1;
 		    continue;
 
 		case CREATSW: 
@@ -153,10 +175,10 @@ main (int argc, char **argv)
 		    continue;
 
 		case HDRSW: 
-		    fheader = -1;
+		    fheader = 1;
 		    continue;
 		case NHDRSW: 
-		    fheader++;
+		    fheader = -1;
 		    continue;
 
 		case PACKSW: 
@@ -181,37 +203,35 @@ main (int argc, char **argv)
 		    continue;
 
 		case TOTALSW: 
-		    all++;
-		    ftotonly++;
+		    ftotonly = 1;
+		    all = 1;
 		    continue;
 		case NTOTLSW: 
-		    if (ftotonly)
-			all = 0;
 		    ftotonly = 0;
 		    continue;
 
 		case PRNTSW: 
-		    printsw++;
+		    printsw = 1;
 		    continue;
 		case NPRNTSW: 
 		    printsw = 0;
 		    continue;
 
 		case LISTSW: 
-		    listsw++;
+		    listsw = 1;
 		    continue;
 		case NLISTSW: 
 		    listsw = 0;
 		    continue;
 
 		case PUSHSW: 
-		    pushsw++;
-		    listsw++;
-		    popsw = 0;
+		    pushsw = 1;
+		    listsw = 1;
+		    popsw  = 0;
 		    continue;
 		case POPSW: 
-		    popsw++;
-		    listsw++;
+		    popsw  = 1;
+		    listsw = 1;
 		    pushsw = 0;
 		    continue;
 	    }
@@ -309,50 +329,61 @@ main (int argc, char **argv)
 	    done (0);
     }
 
-    /* Do all top level folders */
+    /* Allocate initial space to record folder names */
+    maxfolders = NUMFOLDERS;
+    if ((folds = malloc (maxfolders * sizeof(char *))) == NULL)
+	adios (NULL, "unable to allocate storage for folder names");
+
+    /* Do all folders at either top or first level */
     if (all) {
-	fheader = 0;
+	if (!fshort && !ftotonly && (fheader >= 0))
+	    print_header();
 	if (argfolder) {
 	    strcpy (folder, argfolder);
-	    if (pfold (argfolder, msg)) {
+	    if (get_folder_info (argfolder, msg)) {
 		m_replace (pfolder, argfolder);	/* update current folder   */
 		m_update ();			/* update the context file */
 	    }
-	    if (!frecurse)	/* recurse not done in pfold(), */
-		dodir (folder);	/* so just list all level-1 sub-folders */
+	    if (!frecurse)	/* recurse wasn't done in get_folder_info(), */
+		dodir (folder);	/* so just list all level-1 sub-folders      */
 	} else {
+	    /* no folder given, so do them all */
 	    if (msg)
 		admonish (NULL, "no folder given for message %s", msg);
-	    doreadonly ();
+	    do_readonly ();
 	    strcpy (folder, (cp = m_find (pfolder)) ? cp : "");
 	    dodir (".");
 	}
-
 	if (!fshort)
 	    print_totals();	/* print folder/message totals */
-    } else {
-	fheader++;
 
+    } else {
+	if (!fshort && (fheader > 0))
+	    print_header();
 	strcpy (folder, argfolder ? argfolder : m_getfolder ());
+
+	/*
+	 * Check if folder exists.  If not, then see if
+	 * we should create it, or just exit.
+	 */
 	if (stat (strcpy (buf, m_maildir (folder)), &st) == NOTOK) {
 	    if (errno != ENOENT)
 		adios (buf, "error on folder");
-	    switch (fcreat) {
-		case 0:			/* ask before create */
-		    cp = concat ("Create folder \"", buf, "\"? ", NULL);
-		    if (!getanswer (cp))
-			done (1);
-		    free (cp);
-		    break;
-		case -1:		/* do not create */
+	    if (fcreat == 0) {
+		/* ask before creating folder */
+		cp = concat ("Create folder \"", buf, "\"? ", NULL);
+		if (!getanswer (cp))
 		    done (1);
-		    break;
+		free (cp);
+	    } else if (fcreat == -1) {
+		/* do not create, so exit */
+		done (1);
 	    }
 	    if (!makedir (buf))
 		adios (NULL, "unable to create folder %s", buf);
 	}
 
-	if (pfold (folder, msg) && argfolder)
+	if (get_folder_info (folder, msg) && argfolder)
 	    m_replace (pfolder, argfolder);	/* update current folder */
     }
 
@@ -374,7 +405,7 @@ dodir (char *dir)
 
     addir (strcpy (buffer, dir));
     for (i = start; i < foldp; i++) {
-	pfold (folds[i], NULL);
+	get_folder_info (folds[i], NULL);
 	fflush (stdout);
     }
 
@@ -383,100 +414,126 @@ dodir (char *dir)
 }
 
 static int
-pfold (char *fold, char *msg)
+get_folder_info (char *fold, char *msg)
 {
-    int	hack, others, retval = 1;
+    int	retval = 1;
     register char *mailfile;
     register struct msgs *mp = NULL;
 
+    fi.name = fold;
+    fi.error = 0;
+
     mailfile = m_maildir (fold);
-    if (chdir (mailfile) == NOTOK) {
-	if (errno != EACCES)
-	    admonish (mailfile, "unable to change directory to");
-	else
-	    printf ("%22s%c unreadable\n",
-		    fold, strcmp (folder, fold) ? ' ' : '+');
-	return 0;
-    }
+    if (chdir (mailfile) == 0) {
+	if (!fshort || msg || fpack) {
+	    /*
+	     * create message structure and get folder info
+	     */
+	    if (!(mp = m_gmsg (fold))) {
+		admonish (NULL, "unable to read folder %s", fold);
+		return 0;
+	    }
 
-    if (fshort) {
-	printf ("%s\n", fold);
+	    if (msg && !sfold (mp, msg))
+		retval = 0;
 
-	if (!msg && !fpack) {
-	    if (frecurse)
-		dodir (fold);
-	    return retval;
+	    if (fpack)
+		mp = pack_folder (mp);
+
+	    if (!fshort) {
+		total_folders++;
+		total_msgs += mp->nummsg;
+
+		fi.nummsg = mp->nummsg;
+		fi.curmsg = mp->curmsg;
+		fi.lowmsg = mp->lowmsg;
+		fi.hghmsg = mp->hghmsg;
+		fi.others = other_files (mp);
+	    }
+
+	    /* free message structure */
+	    m_fmsg (mp);
 	}
+    } else {
+	fi.error = 1;
     }
 
-    /* read folder and create message structure */
-    if (!(mp = m_gmsg (fold))) {
-	admonish (NULL, "unable to read folder %s", fold);
-	return 0;
+    if (!ftotonly || fshort || fi.error) {
+	/* print summary of folder */
+	print_folder_info (&fi, fold);
     }
 
-    if (msg && !sfold (mp, msg))
-	retval = 0;
-    if (fpack)
-	mp = tfold (mp);
-
-    if (fshort)
-	goto out;
-
-    foldtot++;
-    msgtot += mp->nummsg;
-
-    if (ftotonly)
-	goto out;
-
-    /* print header */
-    if (!fheader++)
-	printf ("\t\tFolder  %*s# of messages (%*srange%*s); cur%*smsg  (other files)\n",
-	    DMAXFOLDER, "", DMAXFOLDER - 2, "", DMAXFOLDER - 2, "",
-	    DMAXFOLDER - 2, "");
-
-    printf ("%22s%c ", fold, strcmp (folder, fold) ? ' ' : '+');
-
-    hack = 0;
-    if (mp->hghmsg == 0)
-	printf ("has   no messages%*s",
-		mp->msgflags & OTHERS ? DMAXFOLDER * 2 + 4 : 0, "");
-    else {
-	printf ("has %*d message%s (%*d-%*d)",
-		DMAXFOLDER, mp->nummsg, (mp->nummsg == 1) ? " " : "s",
-		DMAXFOLDER, mp->lowmsg, DMAXFOLDER, mp->hghmsg);
-	if (mp->curmsg >= mp->lowmsg && mp->curmsg <= mp->hghmsg)
-	    printf ("; cur=%*d", DMAXFOLDER, hack = mp->curmsg);
-    }
-
-    if (mp->msgflags & OTHERS)
-	printf (";%*s (others)", hack ? 0 : DMAXFOLDER + 6, "");
-    printf (".\n");
-
-out: ;
-    others = mp->msgflags & OTHERS;
-    m_fmsg (mp);			/* free folder/message info */
-
-    if (frecurse && others)
+    if (frecurse && (fshort || fi.others) && (fi.error == 0))
 	dodir (fold);
-
     return retval;
 }
 
 
 /*
- * print folder/message totals
+ * Print the header
  */
+
+static void
+print_header (void)
+{
+    printf ("\t\tFolder  %*s# of messages (%*srange%*s); cur%*smsg  (other files)\n",
+	DMAXFOLDER, "", DMAXFOLDER - 2, "", DMAXFOLDER - 2, "", DMAXFOLDER - 2, "");
+}
+
+/*
+ * Print summary of folder information
+ */
+
+static void
+print_folder_info (struct Folder *fi, char *fold)
+{
+    int hack = 0;
+
+    if (fi->error) {
+	printf ("%22s%c is unreadable\n", fold, strcmp (folder, fold) ? ' ' : '+');
+	return;
+    }
+
+    if (fshort) {
+	printf ("%s\n", fold);
+	return;
+    }
+
+    printf ("%22s%c ", fold, strcmp (folder, fold) ? ' ' : '+');
+
+    if (fi->hghmsg == 0)
+	printf ("has   no messages%*s",
+		fi->others ? DMAXFOLDER * 2 + 4 : 0, "");
+    else {
+	printf ("has %*d message%s (%*d-%*d)",
+		DMAXFOLDER, fi->nummsg, (fi->nummsg == 1) ? " " : "s",
+		DMAXFOLDER, fi->lowmsg, DMAXFOLDER, fi->hghmsg);
+	if (fi->curmsg >= fi->lowmsg && fi->curmsg <= fi->hghmsg)
+	    printf ("; cur=%*d", DMAXFOLDER, hack = fi->curmsg);
+    }
+
+    if (fi->others)
+	printf (";%*s (others)", hack ? 0 : DMAXFOLDER + 6, "");
+    printf (".\n");
+}
+
+/*
+ * Print folder/message totals
+ */
+
 static void
 print_totals (void)
 {
     if (!ftotonly)
 	printf ("\n\t\t     ");
     printf ("TOTAL= %*d message%c in %d folder%s.\n",
-	DMAXFOLDER, msgtot, msgtot != 1 ? 's' : ' ',
-	foldtot, foldtot != 1 ? "s" : "");
+	DMAXFOLDER, total_msgs, total_msgs != 1 ? 's' : ' ',
+	total_folders, total_folders != 1 ? "s" : "");
 }
 
+/*
+ * Set the current message and sychronize sequences
+ */
 
 static int
 sfold (struct msgs *mp, char *msg)
@@ -489,17 +546,20 @@ sfold (struct msgs *mp, char *msg)
 	admonish (NULL, "only one message at a time!");
 	return 0;
     }
-    m_setseq (mp);		/* set the previous-sequence */
-    m_setcur (mp, mp->lowsel);
-    m_sync (mp);
-    m_update ();		/* update the context file */
+    m_setseq (mp);		/* set the previous-sequence     */
+    m_setcur (mp, mp->lowsel);	/* set current message           */
+    m_sync (mp);		/* synchronize message sequences */
+    m_update ();		/* update the context file       */
 
     return 1;
 }
 
+/*
+ * Pack the folder
+ */
 
 static struct msgs *
-tfold (struct msgs *mp)
+pack_folder (struct msgs *mp)
 {
     register int hole, msgnum;
     char newmsg[BUFSIZ], oldmsg[BUFSIZ];
@@ -508,7 +568,7 @@ tfold (struct msgs *mp)
 	adios (NULL, "unable to allocate folder storage");
 
     for (msgnum = mp->lowmsg, hole = 1; msgnum <= mp->hghmsg; msgnum++) {
-	if (mp->msgstats[msgnum] & EXISTS) {
+	if (does_exist (mp, msgnum)) {
 	    if (msgnum != hole) {
 		strcpy (newmsg, m_name (hole));
 		strcpy (oldmsg, m_name (msgnum));
@@ -538,6 +598,7 @@ tfold (struct msgs *mp)
     return mp;
 }
 
+
 static void
 addir (char *name)
 {
@@ -573,14 +634,19 @@ addir (char *name)
     *--cp = '\0';
 }
 
+
 static void
 addfold (char *fold)
 {
     register int i, j;
     register char *cp;
 
-    if (foldp > NFOLDERS)
-	adios (NULL, "more than %d folders to report on", NFOLDERS);
+    /* if necessary, reallocate the space for folder names */
+    if (foldp >= maxfolders) {
+	maxfolders += NUMFOLDERS;
+	if ((folds = realloc (folds, maxfolders * sizeof(char *))) == NULL)
+	    adios (NULL, "unable to re-allocate storage for folder names");
+    }
 
     cp = getcpy (fold);
     for (i = start; i < foldp; i++)
@@ -595,6 +661,7 @@ addfold (char *fold)
     folds[foldp++] = cp;
 }
 
+
 static int
 compare (char *s1, char *s2)
 {
@@ -612,7 +679,7 @@ compare (char *s1, char *s2)
  */
 
 static void
-doreadonly (void)
+do_readonly (void)
 {
     int	atrlen;
     char atrcur[BUFSIZ];
@@ -625,5 +692,5 @@ doreadonly (void)
     for (np = m_defs; np; np = np->n_next)
 	if (ssequal (atrcur, np->n_name)
 		&& !ssequal (mhdir, np->n_name + atrlen))
-	    pfold (np->n_name + atrlen, NULL);
+	    get_folder_info (np->n_name + atrlen, NULL);
 }
