@@ -6,7 +6,7 @@
  */
 
 #include <h/mh.h>
-#include <h/formatsbr.h>
+#include <h/fmt_scan.h>
 #include <zotnet/tws/tws.h>
 
 #ifndef	MIME
@@ -602,7 +602,7 @@ build_form (char *form, char *digest, int volume, int issue)
 
     if ((line = malloc ((unsigned) fmtsize)) == NULL)
 	adios (NULL, "unable to allocate format line storage");
-    fmtscan (fmt, line, fmtsize, dat);
+    fmt_scan (fmt, line, fmtsize, dat);
     fputs (line, tmp);
     free (line);
     if (fclose (tmp))
