@@ -32,7 +32,7 @@
 # include <hesiod.h>
 #endif
 
-#include <h/formatsbr.h>
+#include <h/fmt_scan.h>
 #include <h/scansbr.h>
 #include <h/signals.h>
 #include <zotnet/tws/tws.h>
