@@ -126,6 +126,11 @@ main (int argc, char **argv)
 	    msgs[msgp++] = cp;
     }
 
+    /*
+     * If we haven't specified -add, -delete, or -list,
+     * then use -add if a sequence was specified, else
+     * use -list.
+     */
     if (!addsw && !deletesw && !listsw) {
 	if (seqp)
 	    addsw++;
@@ -157,7 +162,7 @@ main (int argc, char **argv)
 	    done (1);
 
     if (publicsw == -1)
-	publicsw = mp->msgflags & READONLY ? 0 : 1;
+	publicsw = (mp->msgflags & READONLY) ? 0 : 1;
     if (publicsw && (mp->msgflags & READONLY))
 	adios (NULL, "folder %s is read-only, so -public not allowed",
 		folder);
@@ -182,12 +187,17 @@ main (int argc, char **argv)
 #endif
     }
 
+    /*
+     * Make sure at least one sequence has been
+     * specified if we are adding or deleting.
+     */
     if (seqp == 0 && (addsw || deletesw))
 	adios (NULL, "-%s requires at least one -sequence argument",
 		addsw ? "add" : "delete");
     seqs[seqp] = NULL;
 
-    if (addsw)
+    /* Adding messages to sequences */
+    if (addsw) {
 	for (seqp = 0; seqs[seqp]; seqp++) {
 	    if (zerosw && !m_seqnew (mp, seqs[seqp], publicsw))
 		done (1);
@@ -196,8 +206,10 @@ main (int argc, char **argv)
 		    if (!m_seqadd (mp, seqs[seqp], msgnum, publicsw))
 			done (1);
 	}
+    }
 
-    if (deletesw)
+    /* Deleting messages from sequences */
+    if (deletesw) {
 	for (seqp = 0; seqs[seqp]; seqp++) {
 	    if (zerosw)
 		for (msgnum = mp->lowmsg; msgnum <= mp->hghmsg; msgnum++)
@@ -209,9 +221,11 @@ main (int argc, char **argv)
 		    if (!m_seqdel (mp, seqs[seqp], msgnum))
 			done (1);
 	}
+    }
 
 #define empty(s) ((s) ? (s) : "")
 
+    /* Listing messages in sequences */
     if (listsw) {
 	if (!seqp) {
 	    for (i = 0; mp->msgattrs[i]; i++)
@@ -225,12 +239,13 @@ main (int argc, char **argv)
 
 #undef empty
 
-	if (debugsw)
+	if (debugsw) {
 	    for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++)
 		if (is_selected (mp, msgnum))
 		    printf ("%*d: %s\n", DMAXFOLDER, msgnum,
 			sprintb (buf, (unsigned) mp->msgstats[msgnum],
 			    m_seqbits (mp)));
+	}
     }
 
     m_replace (pfolder, folder);	/* update current folder         */
