@@ -8,7 +8,7 @@
 #include <h/mh.h>
 #include <h/signals.h>
 #include <h/addrsbr.h>
-#include <h/formatsbr.h>
+#include <h/fmt_scan.h>
 #include <zotnet/tws/tws.h>
 #include <setjmp.h>
 #include <signal.h>
@@ -1007,7 +1007,7 @@ mcomp_format (struct mcomp *c1, struct mcomp *c2)
 	    if (!cp[1])
 		*cp = 0;
 
-	fmtscan (c1->c_fmt, buffer, sizeof buffer - 1, dat);
+	fmt_scan (c1->c_fmt, buffer, sizeof buffer - 1, dat);
 	/* Don't need to append a newline, dctime() already did */
 	c2->c_text = getcpy (buffer);
 
@@ -1048,7 +1048,7 @@ mcomp_format (struct mcomp *c1, struct mcomp *c2)
 	if (cptr)
 	    cptr->c_text = p->pq_error;
 
-	fmtscan (c1->c_fmt, buffer, sizeof buffer - 1, dat);
+	fmt_scan (c1->c_fmt, buffer, sizeof buffer - 1, dat);
 	if (*buffer) {
 	    if (c2->c_text)
 		c2->c_text = add (",\n", c2->c_text);
