@@ -6,7 +6,7 @@
  */
 
 #include <h/mh.h>
-#include <h/formatsbr.h>
+#include <h/fmt_scan.h>
 #include <h/scansbr.h>
 #include <zotnet/mts/mts.h>
 #include <errno.h>
