@@ -111,14 +111,14 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
     while ((cp = *argp++))
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -171,9 +171,10 @@ main (int argc, char **argv)
 		    doteof = 0;
 		    continue;
 	    }
-	else
+	} else {
 	    if (!drft)
 		drft = cp;
+	}
 
     if (!drft)
 	adios (NULL, "usage: %s [switches] file", invo_name);
@@ -260,8 +261,7 @@ main (int argc, char **argv)
 			printf ("%s", field);
 			fprintf (out, "%s", field);
 		    }
-		}
-		else {
+		} else {
 		    printf ("%s: ", name);
 		    fflush (stdout);
 		    i = getln (field, sizeof(field));
