@@ -6,7 +6,7 @@
  */
 
 #include <h/mh.h>
-#include <h/formatsbr.h>
+#include <h/fmt_scan.h>
 #include <h/rcvmail.h>
 #include <zotnet/tws/tws.h>
 
@@ -242,7 +242,7 @@ finished: ;
     scanl = malloc ((size_t) i + 2);
     dat[0] = dat[1] = dat[2] = dat[4] = 0;
     dat[3] = outputlinelen;
-    fmtscan (fmt, scanl, i, dat);
+    fmt_scan (fmt, scanl, i, dat);
     fputs (scanl, out);
 
     if (ferror (out))
