@@ -73,9 +73,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -284,8 +284,7 @@ removeit (struct msgs *mp, int filep, char **files)
 	if (filep > 0) {
 	    vec = files++;	/* filevec[1] */
 	    files[filep] = NULL;
-	}
-	else {
+	} else {
 	    if (mp->numsel > MAXARGS - 2)
 		adios (NULL, "more than %d messages for %s exec",
 			MAXARGS - 2, rmmproc);
@@ -310,12 +309,12 @@ removeit (struct msgs *mp, int filep, char **files)
 	for (i = 0; i < filep; i++)
 	    if (unlink (files[i]) == NOTOK)
 		admonish (files[i], "unable to unlink");
-    }
-    else
+    } else {
 	for (i = mp->lowsel; i <= mp->hghsel; i++)
 	    if (is_selected (mp, i))
 		if (unlink (cp = m_name (i)) == NOTOK)
 		    admonish (cp, "unable to unlink");
+    }
 }
 
 
