@@ -7,7 +7,7 @@
 
 #include <h/mh.h>
 #include <h/addrsbr.h>
-#include <h/formatsbr.h>
+#include <h/fmt_scan.h>
 #include <sys/file.h>		/* L_SET */
 
 extern short ccto;		/* from repl.c */
@@ -224,7 +224,7 @@ finished:
     scanl = malloc ((unsigned)i + 2);
     dat[0] = dat[1] = dat[2] = dat[4] = 0;
     dat[3] = outputlinelen;
-    fmtscan (fmt, scanl, i, dat);
+    fmt_scan (fmt, scanl, i, dat);
     fputs (scanl, out);
     if (badaddrs) {
 	fputs ("\nrepl: bad addresses:\n", out);
@@ -284,7 +284,7 @@ static unsigned int bufsiz=0;	/* current size of buf */
 
 
 /*
- * fmtscan will call this routine if the user includes the function
+ * fmt_scan will call this routine if the user includes the function
  * "(formataddr {component})" in a format string.  "orig" is the
  * original contents of the string register.  "str" is the address
  * string to be formatted and concatenated onto orig.  This routine
