@@ -6,7 +6,7 @@
  */
 
 #include <h/mh.h>
-#include <h/formatsbr.h>
+#include <h/fmt_scan.h>
 #include <h/scansbr.h>
 #include <zotnet/tws/tws.h>
 #include <errno.h>
@@ -75,9 +75,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -147,9 +147,9 @@ main (int argc, char **argv)
 		adios (NULL, "only one folder at a time!");
 	    else
 		folder = path (cp + 1, *cp == '+' ? TFOLDER : TSUBCWF);
-	}
-	else
+	} else {
 	    msgs[msgp++] = cp;
+	}
     }
 
 
