@@ -7,7 +7,7 @@
 
 #include <h/mh.h>
 #include <h/addrsbr.h>
-#include <h/formatsbr.h>
+#include <h/fmt_scan.h>
 #include <h/scansbr.h>
 #include <zotnet/tws/tws.h>
 
@@ -91,10 +91,10 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 		width = MAXSCANL;
 	}
 	dat[3] = slwidth = width;
-	if ((scanl = (char *)malloc( (unsigned) (slwidth + 2) )) == (char *)0)
+	if ((scanl = (char *) malloc((size_t) (slwidth + 2) )) == NULL)
 	    adios (NULL, "unable to malloc scan line (%d bytes)", slwidth+2);
 	if (outnum)
-	    umask( ~ m_gmprot() );
+	    umask(~m_gmprot());
 
 	ncomps = fmt_compile (nfs, &fmt) + 1;
 #ifdef JLR
@@ -126,7 +126,7 @@ scan (FILE *inb, int innum, int outnum, char *nfs, int width, int curflg,
 	used_buf += ncomps+1; *--used_buf = 0;
 	rlwidth = bodycomp && (width > SBUFSIZ) ? width : SBUFSIZ;
 	for (i = ncomps; i--; )
-	    if ((*nxtbuf++ = malloc( rlwidth )) == NULL)
+	    if ((*nxtbuf++ = malloc(rlwidth)) == NULL)
 		adios (NULL, "unable to allocate component buffer");
     }
     /* each-message initialization */
@@ -321,9 +321,9 @@ finished:
 	    }
 	}
 #ifndef JLR
-	fmtscan (fmt, scanl, slwidth, dat);
+	fmt_scan (fmt, scanl, slwidth, dat);
 #else	/* JLR */
-	fmt = fmtscan (fmt, scanl, slwidth, dat);
+	fmt = fmt_scan (fmt, scanl, slwidth, dat);
 	if (!fmt)
 	    fmt = fmt_top;		/* reset for old format files */
 #endif	/* JLR */
