@@ -15,7 +15,7 @@
 # define TMAminc(a)  0
 #endif
 
-#ifdef MIME
+#ifndef MIME
 # define MIMEminc(a) (a)
 #else
 # define MIMEminc(a)  0
@@ -145,9 +145,9 @@ main (int argc, char **argv)
     if ((cp = m_find (invo_name)) != NULL) {
 	ap = brkstring (cp = getcpy (cp), " ", "\n");
 	ap = copyip (ap, arguments);
-    }
-    else
+    } else {
 	ap = arguments;
+    }
     copyip (argv + 1, ap);
     argp = arguments;
 
@@ -155,7 +155,7 @@ main (int argc, char **argv)
     vec[vecp++] = getcpy (m_maildir (""));
 
     while ((cp = *argp++)) {
-	if (*cp == '-')
+	if (*cp == '-') {
 	    switch (smatch (++cp, switches)) {
 		case AMBIGSW: 
 		    ambigsw (cp, switches);
@@ -271,10 +271,15 @@ main (int argc, char **argv)
 		    vec[vecp++] = cp;
 		    continue;
 	    }
-	else
+	} else {
 	    msgs[msgp++] = cp;
+	}
     }
-    if (cp = m_find ("Aliasfile")) {	/* allow Aliasfile: profile entry */
+
+    /*
+     * check for "Aliasfile:" profile entry
+     */
+    if (cp = m_find ("Aliasfile")) {
 	char *dp = NULL;
 
 	for (ap = brkstring(dp = getcpy(cp), " ", "\n"); ap && *ap; ap++) {
@@ -311,12 +316,11 @@ main (int argc, char **argv)
 			break;
 		}
 	    }
-	}
-	else
+	} else {
 	    for (msgnum = 0; msgnum < msgp; msgnum++)
 		msgs[msgnum] = getcpy (m_maildir (msgs[msgnum]));
-    }
-    else {
+	}
+    } else {
 	if (!m_find ("path"))
 	    free (path ("./", TFOLDER));
 
@@ -423,9 +427,9 @@ go_to_it: ;
 		close (out);
 	    }	
 	}
-    }
-    else
+    } else {
 	distfile = NULL;
+    }
 
     if (altmsg == NULL || stat (altmsg, &st) == NOTOK)
 	st.st_mtime = 0, st.st_dev = 0, st.st_ino = 0;
@@ -436,18 +440,17 @@ go_to_it: ;
     vec[0] = r1bindex (postproc, '/');
     closefds (3);
 
-    for (msgnum = 0; msgnum < msgp; msgnum++)
+    for (msgnum = 0; msgnum < msgp; msgnum++) {
 	switch (sendsbr (vec, vecp, msgs[msgnum], &st)) {
 	    case DONE: 
 		done (++status);
-
 	    case NOTOK: 
 		status++;	/* fall */
 	    case OK:
 		break;
 	}
+    }
 
     m_update ();	/* update the context file */
-
     done (status);
 }
