@@ -168,15 +168,19 @@ main (int argc, char **argv)
 
     if (chdir (maildir) == NOTOK)
 	adios (maildir, "unable to change directory to");
+
+    /* read folder and create message structure */
     if (!(mp = m_gmsg (folder)))
 	adios (NULL, "unable to read folder %s", folder);
+
     if (mp->hghmsg == 0)
 	adios (NULL, "no messages in %s", folder);
 
+    /* parse all the message ranges/sequences and set SELECTED */
     for (msgnum = 0; msgnum < msgp; msgnum++)
 	if (!m_convert (mp, msgs[msgnum]))
 	    done (1);
-    m_setseq (mp);
+    m_setseq (mp);	/* set the previous sequence */
 
     if ((nmsgs = read_hdrs (mp, datesw)) <= 0)
 	adios (NULL, "no messages to sort");
@@ -265,9 +269,10 @@ main (int argc, char **argv)
     }
     rename_msgs (mp, dlist);
 
-    m_replace (pfolder, folder);
+    m_replace (pfolder, folder);	/* update current folder         */
     m_sync (mp);
-    m_update ();
+    m_fmsg (mp);			/* free folder/message structure */
+    m_update ();			/* update the context file       */
     done (0);
 }
 
@@ -281,14 +286,14 @@ read_hdrs (struct msgs *mp, char *datesw)
     twscopy (&tb, dtwstime ());
 
     smsgs = (struct smsg *)
-	calloc ((unsigned) (mp->hghsel - mp->lowsel + 2),
+	calloc ((size_t) (mp->hghsel - mp->lowsel + 2),
 	    sizeof *smsgs);
     if (smsgs == NULL)
 	adios (NULL, "unable to allocate sort storage");
 
     s = smsgs;
     for (msgnum = mp->lowsel; msgnum <= mp->hghsel; msgnum++) {
-	if (mp->msgstats[msgnum] & SELECTED) {
+	if (is_selected(mp, msgnum)) {
 	    if (getws (datesw, msgnum, s)) {
 		s->s_msg = msgnum;
 		s++;
@@ -327,8 +332,7 @@ getws (char *datesw, int msg, struct smsg *smsg)
 		}
 		if (!subjsort || subjcomp)
 		    break;
-	    }
-	    else if (subjsort && uleq (nam, subjsort)) {
+	    } else if (subjsort && uleq (nam, subjsort)) {
 		subjcomp = add (buf, subjcomp);
 		while (state == FLDPLUS) {
 		    state = m_getfld (state, nam, buf, sizeof buf, in);
@@ -336,8 +340,7 @@ getws (char *datesw, int msg, struct smsg *smsg)
 		}
 		if (datecomp)
 		    break;
-	    }
-	    else {
+	    } else {
 		/* just flush this guy */
 		while (state == FLDPLUS)
 		    state = m_getfld (state, nam, buf, sizeof buf, in);
