@@ -494,7 +494,7 @@ arginit (char **vec)
 #endif	MHMTS
 
     invo_name = r1bindex (*vec++, '/');
-    m_foil (NULL);
+    m_foil (NULL);		/* foil search of user profile */
     mts_init (invo_name);
 
 #ifndef	SPOP
