@@ -122,7 +122,7 @@ read_termcap(void)
 
     cp = termcap;
     CL = tgetstr ("cl", &cp);
-    if (bp = tgetstr ("pc", &cp))
+    if ((bp = tgetstr ("pc", &cp)))
 	PC = *bp;
     if (tgetnum ("sg") <= 0) {
 	SE = tgetstr ("se", &cp);
