@@ -228,7 +228,9 @@ WhatNow (int argc, char **argv)
     /*NOTREACHED*/
 }
 
-/* EDIT */
+/*
+ * EDIT
+ */
 
 static int  reedit = 0;
 static char *edsave = NULL;
@@ -299,7 +301,7 @@ editfile (char **ed, char **arg, char *file, int use,
 #endif /* not HAVE_LSTAT */
     }
 
-    m_update ();
+    m_update ();	/* update the context file */
     fflush (stdout);
 
     switch (pid = vfork ()) {
@@ -425,7 +427,9 @@ copyf (char *ifile, char *ofile)
 #endif /* HAVE_LSTAT */
 
 
-/* SEND */
+/*
+ * SEND
+ */
 
 static
 sendfile (char **arg, char *file, int pushsw)
@@ -450,7 +454,7 @@ sendfile (char **arg, char *file, int pushsw)
 	return 1;
     }
 
-    m_update ();
+    m_update ();	/* update the context file */
     fflush (stdout);
 
     for (i = 0; (child_id = vfork()) == NOTOK && i < 5; i++)
@@ -830,7 +834,9 @@ sendit (char *sp, char **arg, char *file, int pushed)
 	done (0);
 }
 
-/* WHOM */
+/*
+ * WHOM
+ */
 
 static int
 whomfile (char **arg, char *file)
@@ -839,7 +845,7 @@ whomfile (char **arg, char *file)
     register int vecp;
     char *vec[MAXARGS];
 
-    m_update ();
+    m_update ();	/* update the context file */
     fflush (stdout);
 
     switch (pid = vfork ()) {
