@@ -266,8 +266,7 @@ getport (int rproto, int addrtype, char *response)
 
     isock = &in_socket;
     if (rproto && addrtype != AF_INET) {
-	sprintf (response, "reserved ports not supported for af=%d",
-		addrtype);
+	sprintf (response, "reserved ports not supported for af=%d", addrtype);
 	errno = ENOPROTOOPT;
 	return NOTOK;
     }
